==> chromium-45.0.2454.15.tar.xz: chromium-45.0.2454.15/chrome/browser/chromeos/accessibility/spoken_feedback_event_rewriter.h <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_CHROMEOS_ACCESSIBILITY_SPOKEN_FEEDBACK_EVENT_REWRITER_H_
#define CHROME_BROWSER_CHROMEOS_ACCESSIBILITY_SPOKEN_FEEDBACK_EVENT_REWRITER_H_

#include <vector>

#include "ui/events/event_rewriter.h"

namespace ui {
class KeyEvent;
}

// Receives requests for spoken feedback enabled state and command dispatch.
class SpokenFeedbackEventRewriterDelegate {
 public:
  SpokenFeedbackEventRewriterDelegate() {}
  virtual ~SpokenFeedbackEventRewriterDelegate() {}

  // Returns true when ChromeVox is enabled.
  virtual bool IsSpokenFeedbackEnabled() const;

  // Returns true when |key_event| is dispatched to ChromeVox.
  virtual bool DispatchKeyEventToChromeVox(const ui::KeyEvent& key_event);

 private:
  DISALLOW_COPY_AND_ASSIGN(SpokenFeedbackEventRewriterDelegate);
};

// SpokenFeedbackEventRewriter discards all keyboard events mapped by the spoken
// feedback manifest commands block. It dispatches the associated command name
// directly to spoken feedback. This only occurs whenever spoken feedback is
// enabled.
class SpokenFeedbackEventRewriter : public ui::EventRewriter {
 public:
  SpokenFeedbackEventRewriter();
  ~SpokenFeedbackEventRewriter() override;

  void SetDelegateForTest(
      scoped_ptr<SpokenFeedbackEventRewriterDelegate> delegate);

 private:
  // EventRewriter:
  ui::EventRewriteStatus RewriteEvent(
      const ui::Event& event,
      scoped_ptr<ui::Event>* new_event) override;
  ui::EventRewriteStatus NextDispatchEvent(
      const ui::Event& last_event,
      scoped_ptr<ui::Event>* new_event) override;

  // Active delegate (used for testing).
  scoped_ptr<SpokenFeedbackEventRewriterDelegate> delegate_;

  // Stores all key codes we've captured.
  std::vector<int> captured_key_codes_;

  DISALLOW_COPY_AND_ASSIGN(SpokenFeedbackEventRewriter);
};

#endif  // CHROME_BROWSER_CHROMEOS_ACCESSIBILITY_SPOKEN_FEEDBACK_EVENT_REWRITER_H_

==> chromium-47.0.2526.59.tar.xz: chromium-47.0.2526.59/chrome/browser/chromeos/accessibility/spoken_feedback_event_rewriter.h <==
// Copyright 2015 The Chromium Authors. All rights reserved.
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef CHROME_BROWSER_CHROMEOS_ACCESSIBILITY_SPOKEN_FEEDBACK_EVENT_REWRITER_H_
#define CHROME_BROWSER_CHROMEOS_ACCESSIBILITY_SPOKEN_FEEDBACK_EVENT_REWRITER_H_

#include <vector>

#include "ui/events/event_rewriter.h"

namespace ui {
class KeyEvent;
}

// Receives requests for spoken feedback enabled state and command dispatch.
class SpokenFeedbackEventRewriterDelegate {
 public:
  SpokenFeedbackEventRewriterDelegate();
  virtual ~SpokenFeedbackEventRewriterDelegate() {}

  // Returns true when ChromeVox is enabled.
  virtual bool IsSpokenFeedbackEnabled() const;

  // Returns true when |key_event| is dispatched to ChromeVox.
  virtual bool DispatchKeyEventToChromeVox(const ui::KeyEvent& key_event);

 private:
  // Whether the user previously hit a sequencing prefix command.
  bool is_sequencing_;

  DISALLOW_COPY_AND_ASSIGN(SpokenFeedbackEventRewriterDelegate);
};

// SpokenFeedbackEventRewriter discards all keyboard events mapped by the spoken
// feedback manifest commands block. It dispatches the associated command name
// directly to spoken feedback. This only occurs whenever spoken feedback is
// enabled.
class SpokenFeedbackEventRewriter : public ui::EventRewriter {
 public:
  SpokenFeedbackEventRewriter();
  ~SpokenFeedbackEventRewriter() override;

  void SetDelegateForTest(
      scoped_ptr<SpokenFeedbackEventRewriterDelegate> delegate);

 private:
  // EventRewriter:
  ui::EventRewriteStatus RewriteEvent(
      const ui::Event& event,
      scoped_ptr<ui::Event>* new_event) override;
  ui::EventRewriteStatus NextDispatchEvent(
      const ui::Event& last_event,
      scoped_ptr<ui::Event>* new_event) override;

  // Active delegate (used for testing).
  scoped_ptr<SpokenFeedbackEventRewriterDelegate> delegate_;

  // Stores all key codes we've captured.
  std::vector<int> captured_key_codes_;

  DISALLOW_COPY_AND_ASSIGN(SpokenFeedbackEventRewriter);
};

#endif  // CHROME_BROWSER_CHROMEOS_ACCESSIBILITY_SPOKEN_FEEDBACK_EVENT_REWRITER_H_
